
a
{
  text-decoration: inherit;
  color: inherit;
}

div.tessera
{
  clear: both;
}

div.tessera_done
{
  clear: both;
  background-color: #afa;
  float: left;
}

div.tessera_obsolete
{
  clear: both;
  background-color: gray;
  float: left;
}

div.tessera_open
{
  clear: both;
  background-color: yellow;
  float: left;
}

div.id
{
  float: left;
  display: inline-block;
  padding: 2px;
  width: 6em;
}

div.title_todo
{
  padding: 2px;
  float: left;
  font-weight: bold;
  width: 20em;
  white-space: nowrap;
}

div.title_bug
{
  padding: 2px;
  float: left;
  width: 20em;
  font-weight: bold;
  color: red;
  white-space: nowrap;
}

div.title_wishlist
{
  padding: 2px;
  float: left;
  width: 20em;
  font-weight: bold;
  color: blue;
  white-space: nowrap;
}

div.title_feature
{
  padding: 2px;
  float: left;
  width: 20em;
  font-weight: bold;
  color: blue;
  white-space: nowrap;
}

div.status
{
  padding: 2px;
  float: left;
  width: 10em;
  text-align: center;
}

div.type
{
  padding: 2px;
  float: left;
  width: 10em;
  text-align: center;
}
